/*
 * file FolderLabelProvider.java
 * 
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM - you are allowed to copy, modify and 
 * redistribute this file as part of any program that interfaces with 
 * IBM Rational CM API.
 *
 * com.ibm.rational.teamapi.scout.FolderLabelProvider
 *
 * (C) Copyright IBM Corporation 2004, 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.rational.teamapi.scout;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.swt.graphics.Image;

/**
 * A LabelProvider for ProxyElememts.
 */
public class FolderLabelProvider extends LabelProvider {	
	private Map<ImageDescriptor, Image> imageCache = 
        new HashMap<ImageDescriptor, Image>(11);
	
	/*
	 * @see ILabelProvider#getImage(Object)
	 */
	public Image getImage(Object element) {
		ImageDescriptor descriptor = null;
		if (((ProxyElement)element).couldBeFolder()) {
			descriptor = ScoutPlugin.getImageDescriptor("folder.gif");
		} else
			descriptor = ScoutPlugin.getImageDescriptor("resource.gif");

		//obtain the cached image corresponding to the descriptor
		Image image = (Image)imageCache.get(descriptor);
		if (image == null) {
			image = descriptor.createImage();
			imageCache.put(descriptor, image);
		}
		return image;
	}

	/*
	 * @see ILabelProvider#getText(Object)
	 */
	public String getText(Object element) 
    {
        return ((ProxyElement)element).getText();
	}

    /**
     * Dispose of the images in the cache.
     */
	public void dispose() {
		for (Iterator i = imageCache.values().iterator(); i.hasNext();) {
			((Image) i.next()).dispose();
		}
		imageCache.clear();
	}
}
